@@ -12,7 +12,6 @@ sub new {
     bless $self, $class; # Bless into this class
 
     $class->make_accessor("title");
-    $class->make_accessor("authors");
     $class->make_accessor("year");
     $class->make_accessor("publisher");
 
@@ -36,6 +35,15 @@ sub init_via_xmlref {
     $self->year($year);
 }
 
+##################################################
+sub author {
+##################################################
+    my($self, $nameref) = @_;
+
+    # Only return the first author
+    return ($self->authors($nameref))[0];
+}
+
 ##################################################
 sub authors {
 ##################################################
@@ -100,7 +108,8 @@ book parameters.
 
 =item authors()
 
-Returns a list of the book's authors.
+Returns a list of the book's authors. There's also a C<author()> method
+which just returns the I<first> author.
 
 =item publisher()
 
